@@ -69,8 +69,6 @@ gradf_eps <- function(model_switch,xt_ind,x,a,bpop,b_ind,bocc_ind,num_eps,poped.
   #
   #
   
-  dfeps_de0=zeros(size(xt_ind,1),num_eps)
-  
   if((poped.db$settings$iApproximationMethod==0 || poped.db$settings$iApproximationMethod==1) ){#No interaction
     fg0=feval(poped.db$model$fg_pointer,x,a,bpop,zeros(size(b_ind)[1],size(b_ind)[2]),zeros(size(bocc_ind)[1],size(bocc_ind)[2]))
     
@@ -79,47 +77,7 @@ gradf_eps <- function(model_switch,xt_ind,x,a,bpop,b_ind,bocc_ind,num_eps,poped.
   }
   
   e0=zeros(1,num_eps)
+  dfeps_de0 = grad_all(poped.db$model$ferror_pointer,4,size(xt_ind,1),model_switch,xt_ind,fg0,e0,poped.db)
   
-  #Central approximation
-  if((poped.db$settings$hle_switch==1)){
-    for(i in 1:num_eps){
-      e_plus=e0
-      e_minus=e0
-      e_plus[i] = e_plus[i]+poped.db$settings$hle
-      e_minus[i]= e_minus[i]-poped.db$settings$hle
-      returnArgs <-  feval(poped.db$model$ferror_pointer,model_switch,xt_ind,fg0,e_plus,poped.db) 
-      ferror_plus <- returnArgs[[1]]
-      poped.db <- returnArgs[[2]]
-      returnArgs <-  feval(poped.db$model$ferror_pointer,model_switch,xt_ind,fg0,e_minus,poped.db) 
-      ferror_minus <- returnArgs[[1]]
-      poped.db <- returnArgs[[2]]
-      dfeps_de0[,i]=(ferror_plus-ferror_minus)/(2*poped.db$settings$hle)
-    }
-  } else {
-    #Complex approximation
-    if((poped.db$settings$hle_switch==0)){
-      for(i in 1:num_eps){
-        e_plus=e0
-        e_plus[i] = complex(real=e_plus[i],imaginary=poped.db$settings$hle)
-        returnArgs <- feval(poped.db$model$ferror_pointer,model_switch,xt_ind,fg0,e_plus,poped.db) 
-        ferror_plus <- returnArgs[[1]]
-        poped.db <- returnArgs[[2]]
-        dfeps_de0[,i]=Im(ferror_plus)/poped.db$settings$hle
-      }
-    } else {
-      if((poped.db$settings$hle_switch==30) ){#Automatic differentiation (INTLab)
-        stop("Automatic differentiation not yet implemented in PopED for R")
-        #             e_init = gradientinit(e0)
-        #              returnArgs <- feval(poped.db$model$ferror_pointer,model_switch,xt_ind,fg0,e_init,poped.db) 
-        # ferror_val <- returnArgs[[1]]
-        # poped.db <- returnArgs[[2]]
-        #             dfeps_de0 = ferror_val$dx
-      } else {
-        if((poped.db$settings$hle_switch!=20)){
-          stop(sprintf('Unknown derivative option for gradf_eps'))
-        }
-      }
-    }
-  }
   return(list( dfeps_de0= dfeps_de0,poped.db=poped.db)) 
 }
