@@ -7,7 +7,7 @@ find.largest.index <- function (func.str="sfg",lab="bpop",mat=F,mat.row=T) {
   txt <- grep(paste("^[^\\#]*",lab,"\\[",sep=""),txt,value=T)
   ind <- 0
   if(length(txt)!=0 && !mat)  ind <- gsub(paste("^[^\\#]*",lab,"\\[\\s*(\\d+)\\s*\\].*",sep=""),"\\1",txt)
-  if(length(txt)!=0 && mat && mat.row)  ind <- gsub(paste("^[^\\#]*",lab,"\\[\\s*(\\d+)\\s*,.*?\\].*",sep=""),"\\1",txt)
+  if(length(txt)!=0 && mat && mat.row)  ind <- gsub(paste("^[^\\#]*",lab,"\\[\\s*(\\d+)\\s*,.*?\\].*$",sep=""),"\\1",txt)
   if(length(txt)!=0 && mat && !mat.row)  ind <- gsub(paste("^[^\\#]*",lab,"\\[.*?,\\s*(\\d+)\\s*\\].*",sep=""),"\\1",txt)
   
   max(as.numeric(ind))
@@ -15,7 +15,7 @@ find.largest.index <- function (func.str="sfg",lab="bpop",mat=F,mat.row=T) {
 # 
 #  find.largest.index("sfg","bpop")
 #  find.largest.index("sfg","b")
-#find.largest.index("sfg","bocc",mat=T,mat.row=T)
+#  find.largest.index("sfg","bocc",mat=T,mat.row=T)
 #  find.largest.index("sfg","x")
 #  find.largest.index("sfg","a")
 # 
