@@ -24,19 +24,17 @@ sfg <- function(x,a,bpop,b,bocc){
   return(parameters) 
 }
 
-## -- Define initial design  and design space
+## -- Define model, parameters, initial design
 poped.db <- create.poped.database(ff_fun=ff.PK.1.comp.oral.sd.CL,
                                   fg_fun=sfg,
                                   fError_fun=feps.prop,
                                   bpop=c(CL=0.15, V=8, KA=1.0, Favail=1), 
                                   notfixed_bpop=c(1,1,1,0),
                                   d=c(CL=0.07, V=0.02, KA=0.6), 
-                                  sigma=0.01,
+                                  sigma=c(prop=0.01),
                                   groupsize=32,
                                   xt=c( 0.5,1,2,6,24,36,72,120),
-                                  minxt=0,
-                                  maxxt=120,
-                                  a=70)
+                                  a=c(DOSE=70))
 
 ############# END ###################
 ## Create PopED database
